# steganosaurus Package

This is a simple library to hide data into image file (Steganography) for Python.

## Install

You can install steganosaurus using pip, just run the following command in the command line

    C:\> pip install steganosaurus

## Usage

Please see the wiki for more information:

https://github.com/duongntbk/steganosaurus/wiki

## License

MIT License

https://opensource.org/licenses/MIT